-----------------------------------------------------------------------------------------
-- Start Activity
-----------------------------------------------------------------------------------------

function Astro:StartActivity()
    	print("START! -- Astro:StartActivity()!");
    	self.AreaTimer = Timer();
    	self.StepTimer = Timer();
	self.braindead = {};
	self.CPUBrain = nil;
	self.PlayerBase = SceneMan.Scene:GetArea("Player Base");
	self.Building1 = SceneMan.Scene:GetArea("Building 1");
	self.Building1Basement = SceneMan.Scene:GetArea("Building 1 Basement");
	self.Building1Tower = SceneMan.Scene:GetArea("Building 1 Tower");
	self.Building2 = SceneMan.Scene:GetArea("Building 2");
	self.Building3Tower = SceneMan.Scene:GetArea("Building 3 Tower");
	self.Building3 = SceneMan.Scene:GetArea("Building 3");	
	self.BrainRoom = SceneMan.Scene:GetArea("Brain Room");
	self.GunListA = { "Uzi" };
	self.GunListB = { "Uzi","TommyGun","Pumpgun","Spas12","M16","YAK4700" };
	self.GunListC = { "M1600","Spaz1200" };
	self.GunListD = { "Bazooka","Sniper Rifle","M1600","Rifle Long" };
	self.GunListE = { "M16","Spaz1200","M1600","YAK4700" };
	self.GunListF = { "Heavy Sniper Rifle","Auto Cannon","Revolver Cannon" };
	self.GunListG = { "Napalm Flamer","Gatling Gun","Mauler Shotgun","Spike Launcher" };
    	--------------------------
    	-- Set up teams

    	-- Team 2 is always CPU
    	self.CPUTeam = Activity.TEAM_2;
    
    	--------------------------
    	-- Set up players

    for player = 0, self.PlayerCount - 1 do
        -- Check if we already have a brain assigned
        if not self:GetPlayerBrain(player) then
	    self.braindead[player] = false;
            local brain = CreateAHuman("Brain Robot");
            brain.Pos = Vector(360,744-player*24);
            -- Let the spawn into the world, passing ownership
            MovableMan:AddActor(brain);			
			-- Set the brain to Sentry mode so it doesn't try to leave on you.
			brain.AIMode = Actor.AIMODE_SENTRY;
            -- Set the found brain to be the selected actor at start
            self:SetPlayerBrain(brain, player);
            SceneMan:SetScroll(self:GetPlayerBrain(player).Pos, player);
            self:SetLandingZone(self:GetPlayerBrain(player).Pos, player);
            -- Set the observation target to the brain, so that if/when it dies, the view flies to it in observation mode
            self:SetObservationTarget(self:GetPlayerBrain(player).Pos, player);
        end
    end

    -- Set up AI modes for the Actors that have been added to the scene by the scene definition
    for actor in MovableMan.AddedActors do
        if actor.Team == self.CPUTeam then
			actor.AIMode = Actor.AIMODE_SENTRY;
		if actor.PresetName == "Brain Robot" then
		self.CPUBrain = actor;
		end
		if self.PlayerBase:IsInside(actor.Pos) then
			actor:AddInventoryItem(CreateHDFirearm(self.GunListA[math.random(#self.GunListA)],"Ronin.rte"));
		end
		if self.Building1:IsInside(actor.Pos) then
			actor:AddInventoryItem(CreateHDFirearm(self.GunListB[math.random(#self.GunListB)],"Ronin.rte"));
		end
		if self.Building1Basement:IsInside(actor.Pos) then
			actor:AddInventoryItem(CreateHDFirearm(self.GunListC[math.random(#self.GunListC)],"Ronin.rte"));
		end
		if self.Building1Tower:IsInside(actor.Pos) then
			actor:AddInventoryItem(CreateHDFirearm(self.GunListD[math.random(#self.GunListD)],"Ronin.rte"));
		end
		if self.Building2:IsInside(actor.Pos) then
			actor:AddInventoryItem(CreateHDFirearm(self.GunListE[math.random(#self.GunListE)],"Ronin.rte"));
		end
		if self.Building3Tower:IsInside(actor.Pos) then
			actor:AddInventoryItem(CreateHDFirearm(self.GunListF[math.random(#self.GunListF)],"Coalition.rte"));
		end
		if self.Building3:IsInside(actor.Pos) then
			actor:AddInventoryItem(CreateHDFirearm(self.GunListG[math.random(#self.GunListG)],"Coalition.rte"));
		end
		if self.BrainRoom:IsInside(actor.Pos) then
			actor:AddInventoryItem(CreateHDFirearm(self.GunListA[math.random(#self.GunListA)],"Ronin.rte"));
		end
		end
	end
    -- Set the team's funds to 1000 oz.
    self:SetTeamFunds(1000,Activity.TEAM_1);

    --------------------------
    -- Set up tutorial
    
    self.AreaTimer:Reset();
    self.StepTimer:Reset();
    
end

-----------------------------------------------------------------------------------------
-- Pause Activity
-----------------------------------------------------------------------------------------

function Astro:PauseActivity(pause)
    print("PAUSE! -- Astro:PauseActivity()!");
end

-----------------------------------------------------------------------------------------
-- End Activity
-----------------------------------------------------------------------------------------

function Astro:EndActivity()
    print("END! -- Astro:EndActivity()!");
end

-----------------------------------------------------------------------------------------
-- Update Activity
-----------------------------------------------------------------------------------------

function Astro:UpdateActivity()
    	-- Clear all objective markers, they get re-added each frame
    	self:ClearObjectivePoints();
	if not (self.ActivityState == Activity.OVER) then
    		--------------------------
    		-- Iterate through all human players
		for player = 0, self.PlayerCount - 1 do
        		-- The current player's team
        		local team = self:GetTeamOfPlayer(player);
        		-- Make sure the game is not already ending
            		-- Check if any player's brain is dead
            		local brain = self:GetPlayerBrain(player);
            		if not brain or not MovableMan:IsActor(brain) or not brain:HasObjectInGroup("Brains") then
                		self:SetPlayerBrain(nil, player);
                		-- Try to find a new unasigned brain this player can use instead, or if his old brain entered a craft
                		local newBrain = MovableMan:GetUnassignedBrain(team);
                		-- Found new brain actor, assign it and keep on truckin'
                		if newBrain and self.braindead[player] == false then
                	    		self:SetPlayerBrain(newBrain, player);
                	    		self:SwitchToActor(newBrain, player, team);
                		else
                    			FrameMan:SetScreenText("Your brain has been lost!", player, 333, -1, false);
					self.braindead[player] = true;
                    			-- Now see if all brains of self player's team are dead, and if so, end the game
                    			--if not MovableMan:GetClosestBrainActor(team) then
                        		self.WinnerTeam = self:OtherTeam(team);
                        		ActivityMan:EndActivity();
                    			--end
                		end
            		else
                		-- Update the observation target to the brain, so that if/when it dies, the view flies to it in observation mode
                		self:SetObservationTarget(brain.Pos, player)
        		end
		end
        -- Game over, show the appropriate messages until a certain time
        elseif not self.GameOverTimer:IsPastSimMS(self.GameOverPeriod) then
		for player = 0, self.PlayerCount - 1 do
        		local team = self:GetTeamOfPlayer(player);
        		-- TODO: make more appropriate messages here for run out of funds endings
            		if team == self.WinnerTeam then
                		FrameMan:SetScreenText("VICTOLY!", player, 0, -1, false);
            		else
                		FrameMan:SetScreenText("Your brain has been lost!", player, 0, -1, false);
            		end
		end
	end
    	-- Mark the enemy brain.
	if MovableMan:IsActor(self.CPUBrain) then
	    self:AddObjectivePoint("Destroy!", self.CPUBrain.AboveHUDPos+Vector(0,-16), Activity.TEAM_1, GameActivity.ARROWDOWN);
	else
	    --If it doesn't exist, it's gone!  Player wins!
	    self.WinnerTeam = Activity.TEAM_1;
	    ActivityMan:EndActivity();
	end

      	 -- Sort the objective points
      	self:YSortObjectivePoints();
end